Lemon Dashboard
===============

``lemon-dashboard`` replaces admin index page with dashboard, which contains
widgets. Widgets can be added to or removed from dashboard. Currenty only
two widgets are provided: app list and admin log. But new widgets can be
easily added.
